@@ -32,28 +32,37 @@ if __name__ == '__main__':
             comm = MPI.COMM_WORLD
             test = Test(sys.argv[1], options)
             test.nocapture = True # so we don't lose stdout
-            test.run()
+            tests = test.run()
         except:
             print(traceback.format_exc())
             test.status = 'FAIL'
             test.err_msg = traceback.format_exc()
+            tests = [test]
 
         # collect results
-        results = comm.gather(test, root=0)
+        results = comm.gather(tests, root=0)
         if comm.rank == 0:
-            if not all([isinstance(r, Test) for r in results]):
-                print("\nNot all results gathered are Test objects.  "
-                      "You may have out-of-sync collective MPI calls.\n")
-            total_mem_usage = sum(r.memory_usage for r in results if isinstance(r, Test))
-            test.memory_usage = total_mem_usage
+            for r in results:
+                for tst in r:
+                    if not isinstance(r, Test):
+                        print("\nNot all results gathered are Test objects.  "
+                              "You may have out-of-sync collective MPI calls.\n")
+                        break
+            total_mem_usage = 0.
+            for r in results:
+                for tst in r:
+                    if isinstance(r, Test):
+                        total_mem_usage += r.memory_usage
+                    break  # subtests don't track their own memory usage, so break after 1st one
+            for tst in tests:
+                tst.memory_usage = total_mem_usage
 
             # check for errors and record error message
             for r in results:
-                if test.status != 'FAIL' and r.status in ('SKIP', 'FAIL'):
-                    test.err_msg = r.err_msg
-                    test.status = r.status
-                    if r.status == 'FAIL':
-                        break
+                for test, tst in zip(tests, r):
+                    if test.status != 'FAIL' and tst.status in ('SKIP', 'FAIL'):
+                        test.err_msg = tst.err_msg
+                        test.status = tst.status
 
         save_coverage()
 
@@ -66,4 +75,4 @@ if __name__ == '__main__':
         sys.stderr.flush()
 
         if comm.rank == 0:
-            queue.put(test)
+            queue.put(tests)
